==> open-cluster-management-operator-model-6.5.1-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/KlusterletListFluent.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KlusterletListFluent<A extends KlusterletListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Klusterlet item);
  public A setToItems(Integer index,Klusterlet item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.operator.v1.Klusterlet... items);
  public A addAllToItems(Collection<Klusterlet> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.operator.v1.Klusterlet... items);
  public A removeAllFromItems(Collection<Klusterlet> items);
  public A removeMatchingFromItems(Predicate<KlusterletBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Klusterlet> getItems();
  public List<Klusterlet> buildItems();
  public Klusterlet buildItem(Integer index);
  public Klusterlet buildFirstItem();
  public Klusterlet buildLastItem();
  public Klusterlet buildMatchingItem(Predicate<KlusterletBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KlusterletBuilder> predicate);
  public A withItems(List<Klusterlet> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.operator.v1.Klusterlet... items);
  public Boolean hasItems();
  public KlusterletListFluent.ItemsNested<A> addNewItem();
  public KlusterletListFluent.ItemsNested<A> addNewItemLike(Klusterlet item);
  public KlusterletListFluent.ItemsNested<A> setNewItemLike(Integer index,Klusterlet item);
  public KlusterletListFluent.ItemsNested<A> editItem(Integer index);
  public KlusterletListFluent.ItemsNested<A> editFirstItem();
  public KlusterletListFluent.ItemsNested<A> editLastItem();
  public KlusterletListFluent.ItemsNested<A> editMatchingItem(Predicate<KlusterletBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KlusterletFluent<KlusterletListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/KlusterletListFluent.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KlusterletListFluent<A extends KlusterletListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Klusterlet item);
  public A setToItems(int index,Klusterlet item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.operator.v1.Klusterlet... items);
  public A addAllToItems(Collection<Klusterlet> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.operator.v1.Klusterlet... items);
  public A removeAllFromItems(Collection<Klusterlet> items);
  public A removeMatchingFromItems(Predicate<KlusterletBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Klusterlet> getItems();
  public List<Klusterlet> buildItems();
  public Klusterlet buildItem(int index);
  public Klusterlet buildFirstItem();
  public Klusterlet buildLastItem();
  public Klusterlet buildMatchingItem(Predicate<KlusterletBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<KlusterletBuilder> predicate);
  public A withItems(List<Klusterlet> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.operator.v1.Klusterlet... items);
  public Boolean hasItems();
  public KlusterletListFluent.ItemsNested<A> addNewItem();
  public KlusterletListFluent.ItemsNested<A> addNewItemLike(Klusterlet item);
  public KlusterletListFluent.ItemsNested<A> setNewItemLike(int index,Klusterlet item);
  public KlusterletListFluent.ItemsNested<A> editItem(int index);
  public KlusterletListFluent.ItemsNested<A> editFirstItem();
  public KlusterletListFluent.ItemsNested<A> editLastItem();
  public KlusterletListFluent.ItemsNested<A> editMatchingItem(Predicate<KlusterletBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,KlusterletFluent<KlusterletListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
